.TH REMAP 1
.SH NAME
remap
.SH DOWNLOAD
http://www.icare.univ-lille1.fr/projets/ducos/public/remap/remap-0.4.6.tar.gz
.SH SOURCE FILES
http://www.icare.univ-lille1.fr/projets/ducos/public/remap/remap-0.4.6
.SH SYNOPSIS
.B remap
[\-option ...]
dataset_ref@file_ref
dataset_to_remap_1@file_1
dataset_to_remap_2@file_2 ...
.SH DESCRIPTION
.PP
\fIremap\fP ensures reprojection of geolocated data between various grids
of satellite-embedded instruments.
.PP
The first argument is the user's chosen
reference dataset. A dataset is specified by its name followed by the name of
the file where it is to be found, using the syntax : \fIdataset@file\fP. The dataset is
expected to be a 2-dimensional array. Following dataset arguments will be remapped over the
reference dataset geometry (using a simple nearest-pixel policy for the time being, more clever
reprojection policies may be implemented in future releases). Reprojected datasets will
be put in a common HDF file, along with the reference dataset and its geolocation data
(latitudes, longitudes and acquisition times of each reference pixel). Distances and time
differences between reprojected pixels and their references may also be stored at the user's will.
.PP
The user is given the ability to rename datasets to give them better names in the output file. This
functionality may also be used to resolve collisions between input dataset names. The syntax is
straightforward: \fIold_dataset_name/new_dataset_name@input_file\fP
.PP
In a few cases (e.g., \fBMODIS\fP), some
datasets are 3-dimensional arrays, which are stacks of 2-dimensional arrays
indexed by a plane number (typically a channel number). In this case, the user
is to specify the plane number between brackets, e.g. \fIdataset[1]@file\fP. The convention
adopted here is that the first plane is indexed by one, not by zero.
.PP
Higher-dimensional datasets are currently not supported.
.PP
For the time being, only a few satellite
products are supported, namely \fBMODIS\fP (on AQUA and TERRA), \fBIIR\fP (on CALIPSO)
and \fBSEVIRI\fP (on METEOSAT-8). More products are intended to be integrated in
the future (an issue is the diversity of formats and conventions
in this applicative domain)
.PP
\fIremap\fP will yeld an exit code of zero on success. Any other value means failure.
Error messages are to be sent to the standard error output.
Verbose messages (displayed when the option \-v is set) will be sent to the
standard output.

.SH OPTIONS
.PP
Options of \fIremap\fP :
.TP
.BI "\-c \fIslope,offset\fP"
calibration factors (default: slope = 0.01, offset = 0)
.TP
.BI "\-d \fIdistance\fP"
distance of colocalization, in km (default is 1 km)
.TP
.BI "\-h"
advanced help (displays supported types and implemented user defined projection)
.TP
.BI "\-m \fI<specification for missing value>\fP"
specifies values for missing coordinates, time or data (use -h for details)
.TP
.BI "\-p \fIuser_defined_grid\fP"
specifies a user defined projection instead of a file defined projection (use -h for details)
.TP
.BI "\-o \fIfilename\fP"
output filename (default is \fBremap.out.hdf\fP)
.TP
.BI "\-t \fImax_dtime\fP"
max difference in time from the pixels of reference, in minutes
(may be \fBinf\fP, for infinite, or a strictly positive real number, default is \fBinf\fP)
.TP
.BI \-v
verbose mode
.TP
.BI \-x
extended output (with differences in time and distances from references recorded)
.SH FILES
.PP
Currently supported input products include:

.TP
.BI MODIS/TERRA
MOD021??.A???????.????.???.?????????????*.hdf
.TP
.BI MODIS/AQUA
MYD021??.A???????.????.???.?????????????*.hdf
.TP
.BI IIR/CALIPSO
CAL_IIR_L1-*.hdf
.TP
.BI SEVIRI
H-000-MSG1__-MSG1________-?????????-CYCLE____-????????????

.PP
(each ? means exactly one character, and * any sequence of characters, maybe
empty)

.SH ENVIRONMENT
.PP
\fBREMAP_RAWPATH\fP
path to a directory containing \fBSEVIRI\fP geolocation files,
namely \fIseviri_latitudes.raw\fP and \fIseviri_longitudes.raw\fP
(indeed, \fBSEVIRI\fP geolocation data are not available in products 
as they never change).

.SH COPYRIGHT
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
.SH BUGS
.PP
This is an early version of the software. While main functionalities are
implemented and the software may be used as is to perform remapping, a lot of
bugs surely still wait to get revealed.
.PP
Please report any bug you could find to fabrice.ducos@icare.univ-lille1.fr
.PP
.SH AUTHORS
Fabrice Ducos

.SH SEE ALSO
.PP
